==> solid_5.18.0.orig.tar.xz: solid-5.18.0/src/solid/devices/backends/fakehw/fakeportablemediaplayer.h <==
/*
    Copyright 2006 Davide Bettio <davide.bettio@kdemail.net>
    Copyright 2007 Jeff Mitchell <kde-dev@emailgoeshere.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_FAKEHW_FAKEPORTABLEMEDIAPLAYER_H
#define SOLID_BACKENDS_FAKEHW_FAKEPORTABLEMEDIAPLAYER_H

#include "fakedeviceinterface.h"
#include <solid/devices/ifaces/portablemediaplayer.h>

namespace Solid
{
namespace Backends
{
namespace Fake
{
class FakePortableMediaPlayer : public FakeDeviceInterface, virtual public Solid::Ifaces::PortableMediaPlayer
{
    Q_OBJECT
    Q_INTERFACES(Solid::Ifaces::PortableMediaPlayer)

public:
    explicit FakePortableMediaPlayer(FakeDevice *device);
    ~FakePortableMediaPlayer();

public Q_SLOTS:
    QStringList supportedProtocols() const Q_DECL_OVERRIDE;
    QStringList supportedDrivers(QString protocol) const Q_DECL_OVERRIDE;
    QVariant driverHandle(const QString &driver) const Q_DECL_OVERRIDE;
};
}
}
}

#endif // SOLID_BACKENDS_FAKEHW_FAKEPORTABLEMEDIAPLAYER_H

==> solid_5.54.0.orig.tar.xz: solid-5.54.0/src/solid/devices/backends/fakehw/fakeportablemediaplayer.h <==
/*
    Copyright 2006 Davide Bettio <davide.bettio@kdemail.net>
    Copyright 2007 Jeff Mitchell <kde-dev@emailgoeshere.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_FAKEHW_FAKEPORTABLEMEDIAPLAYER_H
#define SOLID_BACKENDS_FAKEHW_FAKEPORTABLEMEDIAPLAYER_H

#include "fakedeviceinterface.h"
#include <solid/devices/ifaces/portablemediaplayer.h>

namespace Solid
{
namespace Backends
{
namespace Fake
{
class FakePortableMediaPlayer : public FakeDeviceInterface, virtual public Solid::Ifaces::PortableMediaPlayer
{
    Q_OBJECT
    Q_INTERFACES(Solid::Ifaces::PortableMediaPlayer)

public:
    explicit FakePortableMediaPlayer(FakeDevice *device);
    ~FakePortableMediaPlayer();

public Q_SLOTS:
    QStringList supportedProtocols() const override;
    QStringList supportedDrivers(QString protocol) const override;
    QVariant driverHandle(const QString &driver) const override;
};
}
}
}

#endif // SOLID_BACKENDS_FAKEHW_FAKEPORTABLEMEDIAPLAYER_H
